@@ -108,6 +108,9 @@ class Snippets:
     def _attach_types(self):
         type_list = self._function_df.TYPE.unique()
         for func_type in type_list:
+            if not func_type:
+                continue
+
             if func_type == "Transform":
                 for subtype in self._function_df[
                     self._function_df.TYPE == func_type
@@ -262,7 +265,7 @@ def build_pipeline(function_list, steps):
                 )
             pipeline_steps.append(
                 "dsk.pipeline.add_feature_selector([{}])"
-                "".format(",\n{}".format(" " * 40).join(feature_selectors))
+                "".format("\n{}".format(" " * 40).join(feature_selectors))
             )
 
         elif step.get("type") == "tvo":
@@ -291,7 +294,10 @@ def build_pipeline(function_list, steps):
 
         elif step.get("type", None) == "query":
             pipeline_steps.append(
-                """dsk.pipeline.set_input_query("{}")""".format(step.get("name", None))
+                """dsk.pipeline.set_input_query("{query_name}", use_session_preprocessor={use_session_preprocessor})""".format(
+                    query_name=step.get("name", None),
+                    use_session_preprocessor=step.get("use_session_preprocessor", True),
+                )
             )
         else:
             pipeline_steps.append(pipeline_function_help(function_list, step))
