@@ -42,7 +42,7 @@ logger = logging.getLogger("SensiML")
 
 
 def print_list(func):
-    """ This is a wrapper for printing out lists of objects stored in SensiML Cloud """
+    """This is a wrapper for printing out lists of objects stored in SensiML Cloud"""
 
     def wrapper(*args, **kwargs):
         result = func(*args, **kwargs)
@@ -106,7 +106,7 @@ class SensiML(object):
             self.setup_jedi_false()
 
     def setup_jedi_false(self):
-        """ This is a temporary bug fix in ipython autocomplete """
+        """This is a temporary bug fix in ipython autocomplete"""
         try:
             mgc = get_ipython().magic
             mgc("%config Completer.use_jedi = False")
@@ -114,7 +114,7 @@ class SensiML(object):
             pass
 
     def validate_client_version(self, skip_validate=True):
-        """ Perform a Validation check to see if this version of SensiML is up to date with the latest. """
+        """Perform a Validation check to see if this version of SensiML is up to date with the latest."""
 
         if skip_validate:
             return
@@ -150,11 +150,11 @@ class SensiML(object):
         print(self.functions.create_function_call(name).__doc__)
 
     def function_help(self, name):
-        """Prints a shortened description of a function. """
+        """Prints a shortened description of a function."""
         print(function_help(self.functions.function_list[name]))
 
     def list_functions(
-        self, functype=None, subtype=None, kp_functions=False, qgrid=True
+        self, functype=None, subtype=None, kp_functions=False, qgrid=False
     ):
         """Lists all of the functions available on SensiML Cloud
 
@@ -174,16 +174,28 @@ class SensiML(object):
                     {
                         "NAME": f.name,
                         "TYPE": f.type,
-                        "DESCRIPTION": f.description.lstrip("\n").lstrip(" "),
+                        "DESCRIPTION": f.description.lstrip("\n").lstrip(" ")
+                        if f.description
+                        else "",
                         "SUBTYPE": f.subtype,
                         "KP FUNCTION": f.has_c_version,
+                        "UUID": f.uuid,
+                        "LIBRARY": f.library_pack,
                     }
                     for name, f in self.functions.function_list.items()
                 ]
             )
             .sort_values(by=["TYPE", "SUBTYPE"])
             .reset_index(drop=True)[
-                ["NAME", "TYPE", "SUBTYPE", "DESCRIPTION", "KP FUNCTION"]
+                [
+                    "NAME",
+                    "TYPE",
+                    "SUBTYPE",
+                    "DESCRIPTION",
+                    "KP FUNCTION",
+                    "UUID",
+                    "LIBRARY",
+                ]
             ]
         )
 
@@ -195,7 +207,7 @@ class SensiML(object):
 
         if kp_functions:
             df = df[df["KP FUNCTION"] == True][
-                ["NAME", "TYPE", "SUBTYPE", "DESCRIPTION"]
+                ["NAME", "TYPE", "SUBTYPE", "DESCRIPTION", "LIBRARY"]
             ]
 
         if qgrid:
@@ -204,7 +216,7 @@ class SensiML(object):
             return df.reset_index(drop=True)
 
     def delete_project(self):
-        """Deletes a project """
+        """Deletes a project"""
         if self._project is not None:
             self._project.delete()
 
@@ -217,7 +229,9 @@ class SensiML(object):
         """
         return self.projects.build_project_dict()
 
-    def list_segmenters(self,):
+    def list_segmenters(
+        self,
+    ):
         if self._project is None:
             print("project must be set to list segmenters.")
             return None
