@@ -1,5 +1,6 @@
 from sensiml.datamanager.functions import Functions
 from sensiml.datamanager.platformdescriptions import PlatformDescriptions
+from sensiml.datamanager.clientplatformdescriptions import ClientPlatformDescriptions
 from sensiml.datamanager.pipelineseeds import PipelineSeeds
 from sensiml.datamanager.featurefiles import FeatureFiles
 from sensiml.datamanager.projects import Projects
@@ -14,5 +15,6 @@ __all__ = [
     "SegmenterSet",
     "PipelineSeeds",
     "PlatformDescriptions",
+    "ClientPlatformDescriptions",
     "CaptureConfigurations",
 ]
