@@ -34,8 +34,7 @@ class FeatureFile(Base):
 
     @property
     def is_features(self):
-        """If this is a DataFile or FeatureFile
-        """
+        """If this is a DataFile or FeatureFile"""
         return self._is_features
 
     @is_features.setter
