@@ -223,7 +223,7 @@ class KnowledgePack(VisualizeMixin):
             (string): string representation of desired report
 
         """
-        url = "project/{0}/sandbox/{1}/knowledgepack/{2}/report/{3}/".format(
+        url = "project/{0}/knowledgepack/{2}/report/{3}/".format(
             self._project_uuid, self._sandbox_uuid, self.uuid, report_type
         )
         response = self._connection.request(
@@ -342,8 +342,7 @@ class KnowledgePack(VisualizeMixin):
             return None
 
     def stop_recognize_signal(self):
-        """Sends a kill signal to a pipeline
-        """
+        """Sends a kill signal to a pipeline"""
 
         url = "project/{0}/sandbox/{1}/knowledgepack/{2}/recognize_signal/".format(
             self._project_uuid, self._sandbox_uuid, self.uuid
@@ -416,10 +415,10 @@ class KnowledgePack(VisualizeMixin):
     def retrieve(self, silent=False):
         """Gets the result of a prior asynchronous execution of the sandbox.
 
-            Returns:
-                (DataFrame or ModelResultSet): result of executed pipeline, specified by the sandbox
-                (dict): execution summary including execution time and whether cache was used for each
-                step; also contains a feature cost table if applicable
+        Returns:
+            (DataFrame or ModelResultSet): result of executed pipeline, specified by the sandbox
+            (dict): execution summary including execution time and whether cache was used for each
+            step; also contains a feature cost table if applicable
         """
 
         url = "project/{0}/sandbox/{1}/knowledgepack/{2}/recognize_signal/".format(
@@ -435,12 +434,12 @@ class KnowledgePack(VisualizeMixin):
             )
 
     def delete(self):
-        """ Deletes the knowledgepack
+        """Deletes the knowledgepack
 
-            Returns:
-                (DataFrame or ModelResultSet): result of executed pipeline, specified by the sandbox
-                (dict): execution summary including execution time and whether cache was used for each
-                step; also contains a feature cost table if applicable
+        Returns:
+            (DataFrame or ModelResultSet): result of executed pipeline, specified by the sandbox
+            (dict): execution summary including execution time and whether cache was used for each
+            step; also contains a feature cost table if applicable
         """
 
         uuids = {self.uuid}
@@ -464,10 +463,10 @@ class KnowledgePack(VisualizeMixin):
     def save(self, name):
         """Save a knowledpack with a name.
 
-            Returns:
-                (DataFrame or ModelResultSet): result of executed pipeline, specified by the sandbox
-                (dict): execution summary including execution time and whether cache was used for each
-                step; also contains a feature cost table if applicable
+        Returns:
+            (DataFrame or ModelResultSet): result of executed pipeline, specified by the sandbox
+            (dict): execution summary including execution time and whether cache was used for each
+            step; also contains a feature cost table if applicable
         """
 
         uuid_list = []
@@ -654,7 +653,7 @@ class KnowledgePack(VisualizeMixin):
         **kwargs
     ):
         _path = r"{0}".format(folder)
-        url = "project/{0}/sandbox/{1}/knowledgepack/{2}/generate_{3}/v2".format(
+        url = "project/{0}/knowledgepack/{2}/generate_{3}/v2".format(
             self._project_uuid, self._sandbox_uuid, self.uuid, bin_or_lib
         )
         # config = self._sandbox.device_config.copy() # get a regular dictionary
@@ -856,6 +855,40 @@ class KnowledgePack(VisualizeMixin):
                 renderer.render(err_msg)
             return err_msg, False
 
+    def get_build_log(self, renderer=None, save_as=None):
+        url = "knowledgepack/{0}/build-logs/".format(self.uuid)
+
+        response = self._connection.request("get", url)
+        response_data, err = utility.check_server_response(
+            response, is_octet=True, renderer=renderer
+        )
+
+        if "content-disposition" in response_data.headers:
+            if save_as:
+                filename = save_as
+            else:
+                filename = re.findall(
+                    'filename="([^"]+)"', response_data.headers["content-disposition"]
+                )[0]
+
+            with open(filename, "wb") as f:
+                for d in response_data.iter_content(2048):
+                    f.write(d)
+
+            output_path = os.path.join(os.path.abspath("."), filename)
+            if renderer:
+                renderer.render("Build Log saved to\n{0}".format(output_path))
+            else:
+                print("Build Log saved to: {0}".format(output_path))
+
+            return output_path, True
+        else:
+            err_msg = response_data.body
+            print(err_msg)
+            if renderer:
+                renderer.render(err_msg)
+            return err_msg, False
+
     def initialize_from_dict(self, init_dict):
         self._uuid = init_dict["uuid"]
         self._name = init_dict["name"]
@@ -904,8 +937,8 @@ class KnowledgePack(VisualizeMixin):
 def get_knowledgepack(kp_uuid, connection):
     """Gets a KnowledgePack by uuid.
 
-        Returns:
-            a KnowledgePack instance, list of instances, or None
+    Returns:
+        a KnowledgePack instance, list of instances, or None
     """
     url = "knowledgepack/{0}/".format(kp_uuid)
     response = connection.request("get", url)
@@ -923,8 +956,8 @@ def get_knowledgepack(kp_uuid, connection):
 def delete_knowledgepack(kp_uuid, connection):
     """Gets a KnowledgePack by uuid.
 
-        Returns:
-            a KnowledgePack instance, list of instances, or None
+    Returns:
+        a KnowledgePack instance, list of instances, or None
     """
     url = "knowledgepack/{0}/".format(kp_uuid)
     response = connection.request("delete", url)
@@ -933,8 +966,8 @@ def delete_knowledgepack(kp_uuid, connection):
 def get_knowledgepacks(connection):
     """Gets the KnowledgePack(s) created by the sandbox.
 
-        Returns:
-            a KnowledgePack instance, list of instances, or None
+    Returns:
+        a KnowledgePack instance, list of instances, or None
     """
     url = "knowledgepack/"
     response = connection.request("get", url)
