@@ -37,11 +37,11 @@ class SandboxPipeline:
     def add(self, item):
         """Appends a PipelineStep object to the pipeline while performing integrity checks.
 
-            Args:
-                item: a QueryCall, FunctionCall, GeneratorSet, SelectorSet, or TrainAndValidationCall object
+        Args:
+            item: a QueryCall, FunctionCall, GeneratorSet, SelectorSet, or TrainAndValidationCall object
 
-            Returns:
-                nothing, or raises an exception if integrity check fails
+        Returns:
+            nothing, or raises an exception if integrity check fails
         """
         assert isinstance(item, PipelineStep)
         self._steps.append(item)
@@ -77,11 +77,11 @@ class SandboxPipeline:
     def linear_pipeline(self, item):
         """A linear step will automatically set the previous step's output to the currents step's input.
 
-            Args:
-                item (pipeline step): a pipeline step to modify
+        Args:
+            item (pipeline step): a pipeline step to modify
 
-            Returns:
-                pipeline step: pipeline step with updated input_data and outputs attributes
+        Returns:
+            pipeline step: pipeline step with updated input_data and outputs attributes
         """
 
         # if this is the first step
@@ -123,8 +123,8 @@ class SandboxPipeline:
     def remove(self, item):
         """Removes the item from the pipeline.
 
-            Args:
-                item (pipeline step)
+        Args:
+            item (pipeline step)
         """
         if item in self._steps:
             self._steps.remove(item)
@@ -160,12 +160,12 @@ class SandboxPipeline:
     def _get_pipeline_step_value(self, step, key="type"):
         """Returns the value associated with the specified key from the specified step index.
 
-            Args:
-                step (int): step index
-                key (str): key to get the value for
+        Args:
+            step (int): step index
+            key (str): key to get the value for
 
-            Returns:
-                if it exists, the contents associated with the key, otherwise None
+        Returns:
+            if it exists, the contents associated with the key, otherwise None
         """
         if len(self._steps) == 0:
             print("There are no steps associated with this pipeline.")
@@ -196,8 +196,8 @@ class SandboxPipeline:
     def _check_integrity(self):
         """Checks the integrity of the pipeline as a whole.
 
-            Returns:
-                 True if successful, otherwise raises an exception
+        Returns:
+             True if successful, otherwise raises an exception
         """
         _aggregated_errors = []
 
@@ -369,7 +369,7 @@ class Sandbox(object):
         )
 
     def _check_sandbox_inserted(self, insert=False):
-        """ Checks for a uuid and warns the user if none exists """
+        """Checks for a uuid and warns the user if none exists"""
         if self.uuid == "":
             if insert:
                 print("Sandbox was not on server, attempting to insert now...", end="")
@@ -427,8 +427,8 @@ class Sandbox(object):
     def knowledgepack(self, kp_uuid):
         """Gets the KnowledgePack(s) created by the sandbox.
 
-            Returns:
-                a KnowledgePack instance, list of instances, or None
+        Returns:
+            a KnowledgePack instance, list of instances, or None
         """
         url = "knowledgepack/{0}/".format(kp_uuid)
         response = self._connection.request("get", url)
@@ -441,8 +441,8 @@ class Sandbox(object):
     def get_knowledgepacks(self):
         """Gets the KnowledgePack(s) created by the sandbox.
 
-            Returns:
-                a KnowledgePack instance, list of instances, or None
+        Returns:
+            a KnowledgePack instance, list of instances, or None
         """
         url = "project/{0}/sandbox/{1}/knowledgepack/".format(
             self._project.uuid, self.uuid
@@ -554,10 +554,10 @@ class Sandbox(object):
     def execute(self):
         """Executes the sandbox pipeline and returns results.
 
-            Returns:
-                (DataFrame or ModelResultSet): result of executed pipeline, specified by the sandbox
-                (dict): execution summary including execution time and whether cache was used for each
-                step; also contains a feature cost table if applicable
+        Returns:
+            (DataFrame or ModelResultSet): result of executed pipeline, specified by the sandbox
+            (dict): execution summary including execution time and whether cache was used for each
+            step; also contains a feature cost table if applicable
         """
         self.submit()
 
@@ -576,11 +576,12 @@ class Sandbox(object):
         if err is False:
             return response_data
 
-    def auto(self, auto_params, seed, renderer=None):
+    def auto(self, auto_params, seed, renderer=None, version=1):
         """Submits the automation job for asynchronous execution and returns the task status."""
 
         if renderer is None:
             renderer = BaseRenderer()
+        """
         if seed.name == "Custom":
             if self.pipeline.to_list()[-1]["type"] != "tvo":
                 renderer.render(
@@ -607,10 +608,17 @@ class Sandbox(object):
                 + "pipeline (query, data file, and segmenter steps are okay)."
             )
             return 0
+        """
+        if version == 1:
+            execution_type = "auto"
+        elif version == 2:
+            execution_type = "automlv2"
+        else:
+            raise Exception("Version {} not supported.".format(version))
 
         data = {
             "run_parallel": True,
-            "execution_type": "auto",
+            "execution_type": execution_type,
             "auto_params": auto_params,
         }
 
@@ -638,10 +646,10 @@ class Sandbox(object):
     def retrieve(self, silent=False, page_index=0, **kwargs):
         """Gets the result of a prior asynchronous execution of the sandbox.
 
-            Returns:
-                (DataFrame or ModelResultSet): result of executed pipeline, specified by the sandbox
-                (dict): execution summary including execution time and whether cache was used for each
-                step; also contains a feature cost table if applicable
+        Returns:
+            (DataFrame or ModelResultSet): result of executed pipeline, specified by the sandbox
+            (dict): execution summary including execution time and whether cache was used for each
+            step; also contains a feature cost table if applicable
         """
         if self._dirty:
             self.update()
@@ -657,6 +665,9 @@ class Sandbox(object):
                 response_data, self._handle_result, silent=silent
             )
 
+        print(response.json())
+        return response
+
     def kill_pipeline(self):
         url = "project/{0}/sandbox-async/{1}/".format(self._project.uuid, self.uuid)
         response = self._connection.request("delete", url)
@@ -711,8 +722,8 @@ class Sandbox(object):
     def initialize_from_dict(self, init_dict):
         """Populates a single sandbox from a dictionary of properties.
 
-            Args:
-                (dict): contains uuid, name, cache_enabled, and pipeline
+        Args:
+            (dict): contains uuid, name, cache_enabled, and pipeline
         """
         self.uuid = init_dict["uuid"]
         self.name = init_dict["name"]
@@ -731,9 +742,9 @@ class Sandbox(object):
     def add_step(self, step):
         """Adds the step to the sandbox pipeline.
 
-            Args:
-                step (pipeline step): a QueryCall, FunctionCall, GeneratorSet, SelectorSet, or
-                                      TrainAndValidationCall object
+        Args:
+            step (pipeline step): a QueryCall, FunctionCall, GeneratorSet, SelectorSet, or
+                                  TrainAndValidationCall object
         """
         self._pipeline.add(step)
         self._dirty = True
@@ -741,10 +752,10 @@ class Sandbox(object):
     def update_step(self, step, index):
         """Update a step with new values
 
-            Args:
-                step (pipeline step): a QueryCall, FunctionCall, GeneratorSet, SelectorSet, or
-                                      TrainAndValidationCall object
-                index (int): index of the pipeline step to update
+        Args:
+            step (pipeline step): a QueryCall, FunctionCall, GeneratorSet, SelectorSet, or
+                                  TrainAndValidationCall object
+            index (int): index of the pipeline step to update
 
         """
         step = self._pipeline.replace_linear_pipeline(step, index)
@@ -754,12 +765,12 @@ class Sandbox(object):
     def add_linear_step(self, step, overwrite=True):
         """Adds a linear step to the pipeline (will automatically use the previous step's output as input).
 
-            Args:
-                step (pipeline step): a QueryCall, FunctionCall, GeneratorSet, SelectorSet, or
-                    TrainAndValidationCall object
-                overwrite (boolean): when adding multiple instances of the same transform, set
-                    overwrite to False for the additional steps and the first instance will not
-                    be overwritten (default is True)
+        Args:
+            step (pipeline step): a QueryCall, FunctionCall, GeneratorSet, SelectorSet, or
+                TrainAndValidationCall object
+            overwrite (boolean): when adding multiple instances of the same transform, set
+                overwrite to False for the additional steps and the first instance will not
+                be overwritten (default is True)
 
         """
         if not overwrite or self._pipeline._check_duplicate_outputs(step) is None:
@@ -772,9 +783,9 @@ class Sandbox(object):
     def remove_step(self, step):
         """Removes a step from the pipeline.
 
-            Args:
-                step (pipeline step): a QueryCall, FunctionCall, GeneratorSet, SelectorSet, or
-                                      TrainAndValidationCall object to remove from the pipeline
+        Args:
+            step (pipeline step): a QueryCall, FunctionCall, GeneratorSet, SelectorSet, or
+                                  TrainAndValidationCall object to remove from the pipeline
         """
         self._pipeline.remove(step)
         self._dirty = True
