@@ -55,6 +55,7 @@ class Pipeline(object):
         self._group_columns = None
         self._label_column = None
         self._data_columns = None
+        self._use_query_session = False
 
         if name:
             self._id = "{}".format(name)
@@ -112,11 +113,11 @@ class Pipeline(object):
             print("Error: group_columns must be a list.")
 
     def get_automl_iteration_metrics(self):
-        """ 
-            Results of automl stats for each iteration
-            
-            Returns:
-                DataFrame: Automl resutls stats
+        """
+        Results of automl stats for each iteration
+
+        Returns:
+            DataFrame: Automl resutls stats
         """
 
         url = "project/{0}/sandbox/{1}/automl-iteration-metrics/".format(
@@ -367,9 +368,16 @@ class Pipeline(object):
         return self.get_results(lock=True, wait_time=wait_time, silent=silent, **kwargs)
 
     def auto(
-        self, auto_params, run_parallel=True, lock=True, silent=True, renderer=None
+        self,
+        auto_params,
+        run_parallel=True,
+        lock=True,
+        silent=True,
+        renderer=None,
+        version=1,
     ):
-        """Execute automated pipeline asynchronously.
+        """
+        Execute automated pipeline asynchronously.
 
         The automated pipeline is used to find optimal parameters with a genetic algorithm. The genetic algorithm starts with a user-defined
         randomized population (pipelines) and generates models from them and tests them, keeps a subset of high-performing combinations, and
@@ -382,88 +390,114 @@ class Pipeline(object):
         given below.
 
         Args:
-            seed (str): Pipeline templates that focus on different feature libraries. Options and definitions are given below.
-                Basic Features: Generates a set of all-purpose, high-performance features using statistical, energy, and rate of change feature
-                    generators. The seed then performs feature selection and model generation algorithms with a genetic algorithm to optimize
-                    pipeline parameters.
-                Advanced Features: Generates a comprehensive set of features using statistical, energy, amplitude, shape, time, and rate of
-                    change feature generators. The seed then performs feature selection and model generation algorithms with a genetic algorithm
-                    to optimize pipeline parameters.
-                Histogram_Features: Generates a set of histogram features and then performs feature selection and model generation algorithms
-                    with a genetic algorithm to optimize pipeline parameters.
-                Downsampled_Features: Generates a set of downsampled features and then performs feature selection and model generation algorithms
-                    with a genetic algorithm to optimize pipeline parameters.
-                Custom: Uses the user-defined pipeline to extract features and then searches for optimal parameters for the feature selection step,
-                    if defined, and the model generation step (required) using a genetic algorithm.
+            seed (str) : Pipeline templates that focus on different feature libraries. Options and definitions are given below.
+
+                - **Basic Features**: Generates a set of all-purpose, high-performance features using statistical, energy, and rate of change feature
+                  generators. The seed then performs feature selection and model generation algorithms with a genetic algorithm to optimize
+                  pipeline parameters.
+
+                - **Advanced Features**: Generates a comprehensive set of features using statistical, energy, amplitude, shape, time, and rate of
+                  change feature generators. The seed then performs feature selection and model generation algorithms with a genetic algorithm
+                  to optimize pipeline parameters.
+
+                - **Histogram_Features**: Generates a set of histogram features and then performs feature selection and model generation algorithms
+                  with a genetic algorithm to optimize pipeline parameters.
+
+                - **Downsampled_Features**: Generates a set of downsampled features and then performs feature selection and model generation algorithms
+                  with a genetic algorithm to optimize pipeline parameters.
+
+                - **Custom**: Uses the user-defined pipeline to extract features and then searches for optimal parameters for the feature selection step,
+                  if defined, and the model generation step (required) using a genetic algorithm.
 
             params (dict) : Parameters of the genetic algorithm to optimize the pipelines. Definition and options of the parameters are given below.
-                search_steps, (list, ['selectorset', 'tvo']): it is used to define which libraries in the pipelines will be optimized.
-                population_size, (int, 10): Initial number of randomly created pipelines.
-                iterations, (int, 1): Repetition number of optimization process
-                mutation_rate, (float, 0.1): Random changes from the previous population.
-                recreation_rate, (float, 0.1): Rate of randomly created pipelines for next generation.
-                survivor_rate, (float, 0.5): Ratio of the population that will be transferred to next generation.
-                number_of_models_to_return, (int, 5): Number of pipeline that will return to user.
-                allow_unknown, (bool, False): Allows creating unknown prediction results for the vectors. A vector is classified as an unknown if it
-                    cannot be recognized by any neurons.
-                demean_segments, (bool, False): Removes the mean from the input data before extracting features.
-                validation_method, (Stratified Shuffle Split): Validation method that will be used in optimization
-                balance_data, (bool, False): Use Undersampling of the Majority classes to balance the data prior to Model Building
-                outlier_filter, (bool, False): Filter outliers using Isolation Forest Filter with a filter percent of 5.
-                fitness (dict): Fitness parameters are combination of statistical and cost variables. It is used to evaluate the performance of
-                    the models found by the algorithm. The user will define the coefficient scores for the parameters to define the priority of
-                    the parameters in the fitness score. Definition and options of the parameters are given below.
+                - search_steps, (list, ['selectorset', 'tvo']): it is used to define which libraries in the pipelines will be optimized.
 
-                    statistical variables:
-                        accuracy: The degree of correctness of all vectors
-                        f1_score: Measures of the test's accuracy
-                        precision: Proportion of positive identifications that is actually correct
-                        sensitivity: Measures of the proportion of actual positives that are correctly identified
-                        specificity: Measures of the proportion of actual negatives that are correctly identified
-                        positive_predictive_rate: Ratio of "true positive" is the event that the test makes a positive prediction
-                    cost variables:
-                        neurons: Number of neurons that used in the model
-                        features: Number of features that used in the model,
+                - population_size, (int, 10): Initial number of randomly created pipelines.
+
+                - iterations, (int, 1): Repetition number of optimization process
+
+                - mutation_rate, (float, 0.1): Random changes from the previous population.
+
+                - recreation_rate, (float, 0.1): Rate of randomly created pipelines for next generation.
+
+                - survivor_rate, (float, 0.5): Ratio of the population that will be transferred to next generation.
+
+                - number_of_models_to_return, (int, 5): Number of pipeline that will return to user.
+
+                - allow_unknown, (bool, False): Allows creating unknown prediction results for the vectors. A vector is classified as an unknown if it
+
+                    cannot be recognized by any neurons.
+                - demean_segments, (bool, False): Removes the mean from the input data before extracting features.
+
+                - validation_method, (Stratified Shuffle Split): Validation method that will be used in optimization
+
+                - balance_data, (bool, False): Use Undersampling of the Majority classes to balance the data prior to Model Building
+
+                - outlier_filter, (bool, False): Filter outliers using Isolation Forest Filter with a filter percent of 5.
+
+                - fitness (dict): Fitness parameters are combination of statistical and cost variables. It is used to evaluate the performance of
+                  the models found by the algorithm. The user will define the coefficient scores for the parameters to define the priority of
+                  the parameters in the fitness score. Definition and options of the parameters are given below.
+
+                    - statistical variables:
+                        - accuracy: The degree of correctness of all vectors
+
+                        - f1_score: Measures of the test's accuracy
+
+                        - precision: Proportion of positive identifications that is actually correct
+
+                        - sensitivity: Measures of the proportion of actual positives that are correctly identified
+
+                        - specificity: Measures of the proportion of actual negatives that are correctly identified
+
+                        - positive_predictive_rate: Ratio of "true positive" is the event that the test makes a positive prediction
+
+
+                    - cost variables:
+                        - neurons: Number of neurons that used in the model
+
+                        - features: Number of features that used in the model,
 
             lock (bool, False): Ping for results every 30 seconds until the process finishes.
             silent (bool, True): Silence status updates.
 
         Example:
+            .. code-block:: python
 
-            activity_data = dsk.datasets.load_activity_raw()
-            dsk.upload_dataframe('activity_data.csv', activity_data, force=True)
+                activity_data = dsk.datasets.load_activity_raw()
+                dsk.upload_dataframe('activity_data.csv', activity_data, force=True)
 
-            dsk.pipeline.reset()
-            dsk.pipeline.set_input_data('activity_data.csv',
-                                data_columns = ['accelx', 'accely', 'accelz', 'gyrox', 'gyroy', 'gyroz'],
-                                group_columns = ['Subject','Class', 'Rep'],
-                                label_column = 'Class')
+                dsk.pipeline.reset()
+                dsk.pipeline.set_input_data('activity_data.csv',
+                                            data_columns = ['accelx', 'accely', 'accelz', 'gyrox', 'gyroy', 'gyroz'],
+                                            group_columns = ['Subject','Class', 'Rep'],
+                                            label_column = 'Class')
 
-            dsk.pipeline.add_transform("Windowing", params={"window_size": 100, "delta": 100 })
+                dsk.pipeline.add_transform("Windowing", params={"window_size": 100, "delta": 100 })
 
-            results, summary = dsk.pipeline.auto({'seed': 'Basic Features',
-                                                  'params':{"search_steps": ['selectorset', 'tvo'],
-                                                            "population_size": 10,
-                                                            "iterations": 1,
-                                                            "mutation_rate": 0.1,
-                                                            "recreation_rate": 0.1,
-                                                            "survivor_rate": 0.5,
-                                                            "number_of_models_to_return": 5,
-                                                            "run_parallel": True,
-                                                            "allow_unknown": False,
-                                                            "validation_method": "'Stratified Shuffle Split'",
-                                                            "fitness": {'neurons': 0.5,
-                                                                        'accuracy': 1.0,
-                                                                        'f1_score': 0.0,
-                                                                        'features': 0.3,
-                                                                        'precision': 0.0,
-                                                                        'sensitivity': 0.7,
-                                                                        'specificity': 0.0,
-                                                                        'positive_predictive_rate': 0.0},
+                results, summary = dsk.pipeline.auto({'seed': 'Basic Features',
+                                                    'params':{"search_steps": ['selectorset', 'tvo'],
+                                                                "population_size": 10,
+                                                                "iterations": 1,
+                                                                "mutation_rate": 0.1,
+                                                                "recreation_rate": 0.1,
+                                                                "survivor_rate": 0.5,
+                                                                "number_of_models_to_return": 5,
+                                                                "run_parallel": True,
+                                                                "allow_unknown": False,
+                                                                "validation_method": "'Stratified Shuffle Split'",
+                                                                "fitness": {'neurons': 0.5,
+                                                                            'accuracy': 1.0,
+                                                                            'f1_score': 0.0,
+                                                                            'features': 0.3,
+                                                                            'precision': 0.0,
+                                                                            'sensitivity': 0.7,
+                                                                            'specificity': 0.0,
+                                                                            'positive_predictive_rate': 0.0},
 
-                                                              }})
+                                                                }})
 
-            results.summarize()
+                results.summarize()
 
 
 
@@ -477,14 +511,15 @@ class Pipeline(object):
 
         seed = self._kb.seeds.get_seed_by_name(auto_params["seed"])
         success = self._sandbox.auto(
-            auto_params=auto_params, seed=seed, renderer=renderer
+            auto_params=auto_params, seed=seed, renderer=renderer, version=version
         )
         if success:
             return self.get_results(lock=lock, silent=silent, renderer=renderer)
         return (None, None)
 
     def grid_search(self, grid_params, run_parallel=True, lock=True, silent=True):
-        """Grid search is a parameter optimization method that exhaustivley searches over a gridded parameter space.
+        """
+        Grid search is a parameter optimization method that exhaustivley searches over a gridded parameter space.
         Grid search returns will return the score each parameter combination for f1, precision and sensitivity so that
         you can choose the best performing combination to build a knowledge pack with.
 
@@ -511,7 +546,7 @@ class Pipeline(object):
 
             grid_params = {"Name Of Function":{"Name of Parameter 1":[ A, B, C],
                                             "Name of Parameter 2":[ D, E]},
-                          "Name of Function 2":{"Name of Parameter":[1, 2, 3, 4, 5, 6]}}
+                                            "Name of Function 2":{"Name of Parameter":[1, 2, 3, 4, 5, 6]}}
 
         Example:
 
@@ -666,7 +701,7 @@ class Pipeline(object):
             self._sandbox.delete_cache()
 
     def reset(self, delete_cache=False):
-        """ Reset the current pipeline steps.
+        """Reset the current pipeline steps.
 
         Args:
             delete_cache (bool, False): Delete the cache from KB cloud.
@@ -682,6 +717,7 @@ class Pipeline(object):
         self._validation_call = None
         self._group_columns = None
         self._label_column = None
+        self._use_query_session = False
 
         if delete_cache:
             print(
@@ -706,7 +742,7 @@ class Pipeline(object):
             self._sandbox.delete()
 
     def _preprocess(self, segmenterid):
-        """ adds the segmenter preprocess steps to the pipeline """
+        """adds the segmenter preprocess steps to the pipeline"""
 
         try:
             segmenter = self._project.get_segmenters().loc[segmenterid]
@@ -731,15 +767,21 @@ class Pipeline(object):
             self._data_columns.add(transform["actual_name"])
             print("Adding Preprocess Transform {}".format(transform["params"]["name"]))
 
-    def set_input_query(self, name):
+        self._use_query_session = True
+
+    def set_input_query(self, name, use_session_preprocessor=True):
         """Set the input data to be a stored query.
 
         Args:
             name (str): The name of the saved query.
+            use_session_preprocessor (bool): Use the autosegmentation algorithms for this pipeline
+             (if there is one). When this is true, the segmentation algorithm will not show up in
+             the pipeline but will be included in the firmware generation.
         """
 
         query_call = self._kb.functions.create_query_call(name)
         query_call.query = self._project.queries.get_query_by_name(name)
+        query_call.use_session_preprocessor = use_session_preprocessor
 
         self._dataset = query_call
 
@@ -753,7 +795,8 @@ class Pipeline(object):
 
         self._add_initial_data()
 
-        self._preprocess(query_call.query.segmenter)
+        if use_session_preprocessor:
+            self._preprocess(query_call.query.segmenter)
 
     def set_input_data(
         self, name, data_columns=None, group_columns=None, label_column=None
@@ -943,19 +986,19 @@ class Pipeline(object):
 
     def add_augmentation(self, augmentation, params={}):
         """
-            Add augmentation set to the pipeline.
+        Add augmentation set to the pipeline.
 
-            Args:
-                augmentation (List): List of dictionaries containing time series augmentations
-                params (dict, {}): Parameters of the feature selector set.
+        Args:
+            augmentation (List): List of dictionaries containing time series augmentations
+            params (dict, {}): Parameters of the feature selector set.
+
+        Examples:
+            >>> dsk.pipeline.add_augmentation([{"name": "Add Noise", "params": {"scale": [0.05, 0.1, 0.15 ],  # , 0.1, 0.15
+            >>>                                                                 "target_labels": ['idle','walking'],
+            >>>                                                                 "target_sensors": ['AccelerometerX', 'GyroscopeX']
+            >>>                                                                }}
+            >>>                                   ])
 
-            Examples:
-                >>> dsk.pipeline.add_augmentation([{"name": "Add Noise", "params": {"scale": [0.05, 0.1, 0.15 ],  # , 0.1, 0.15
-                >>>                                                                 "target_labels": ['idle','walking'],
-                >>>                                                                 "target_sensors": ['AccelerometerX', 'GyroscopeX']   
-                >>>                                                                }}
-                >>>                                   ])
-      
         """
 
         self._add_augmentation(augmentation, params)
@@ -1032,7 +1075,8 @@ class Pipeline(object):
         self._add_tvo(self._tvo_call)
 
     def iterate_columns(self, fg, n_columns=None, columns=None):
-        """ Builds Multiple Feature generators by iterating over the input columns
+        """
+        Builds Multiple Feature generators by iterating over the input columns
 
         Args:
             fg (dict): Single input feature generator folowing the standard format
@@ -1045,8 +1089,7 @@ class Pipeline(object):
 
         >> print(fg_new)
         >> [{'name': 'Downsample with Min Max Scaling', 'params': {'columns': ['gyrX'], 'new_length': 15}},
-            {'name': 'Downsample with Min Max Scaling', 'params': {'columns': ['gyrX'], 'new_length': 15}}]
-
+        {'name': 'Downsample with Min Max Scaling', 'params': {'columns': ['gyrX'], 'new_length': 15}}]
         """
 
         if n_columns is None:
@@ -1085,6 +1128,14 @@ class Pipeline(object):
 
     def _add_transform(self, transform, overwrite=True):
 
+        if (
+            self.get_function_type(transform["name"]) == "Segmenter"
+            and self._use_query_session
+        ):
+            raise Exception(
+                "You have set use query session True, can't add a segmentation step."
+            )
+
         self._check_for_input_data()
 
         logger.debug("transform:" + str(transform["name"]))
@@ -1226,7 +1277,7 @@ class Pipeline(object):
         self._sandbox.add_linear_step(selector_set)
 
     def _add_initial_data(self):
-        """Add the raw data call to the pipeline """
+        """Add the raw data call to the pipeline"""
         if self.get_pipeline_length() != 0:
             raise PipelineOrderException(
                 "Input data must be the first step in the pipeline"
